==> prevnext-2.0.8.tar.gz: prevnext/src/Plugin/views/field/PrevNextLinks.php <==
<?php

namespace Drupal\prevnext\Plugin\views\field;

use Drupal\views\Plugin\views\field\FieldPluginBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\prevnext\PrevNextServiceInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\views\ResultRow;
use Drupal\Core\Url;

/**
 * A handler to provide display for the Previous and Next links.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("prevnext_links_field")
 */
class PrevNextLinks extends FieldPluginBase {

  /**
   * Returns the prevnext.service service.
   *
   * @var \Drupal\prevnext\PrevNextServiceInterface
   */
  protected $prevnext;

  /**
   * Returns the config.factory service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Constructs a new PrevNextLinks instance.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin ID for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\prevnext\PrevNextServiceInterface $prevnext
   *   Interface for the main PrevNext service file.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   Defines the interface for a configuration object factory.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, PrevNextServiceInterface $prevnext, ConfigFactoryInterface $config_factory) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->prevnext = $prevnext;
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('prevnext.service'),
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function query() {}

  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values) {
    $build = [];

    /** @var \Drupal\node\NodeInterface $node */
    $node = $this->getEntity($values);

    if (!$node) {
      return $build;
    }

    $config = $this->configFactory->get('prevnext.settings');
    $node_types = $config->get('prevnext_enabled_nodetypes');

    if (empty($node_types[$node->getType()])) {
      return $build;
    }

    $previous_next = $this->prevnext->getPreviousNext($node);
    $cache = [
      'contexts' => [
        'url',
        'user.permissions',
      ],
      'tags' => [
        'config:prevnext.settings',
        'node_list',
      ],
    ];

    $build['prevnext_previous'] = [
      '#theme' => 'prevnext',
      '#direction' => 'previous',
      '#text' => $this->t('Previous'),
      '#nid' => $previous_next['prev'],
      '#url' => Url::fromUserInput('/node/' . $previous_next['prev'])->toString(),
      '#void' => empty($previous_next['prev']),
      '#cache' => $cache,
    ];

    $build['prevnext_next'] = [
      '#theme' => 'prevnext',
      '#direction' => 'next',
      '#text' => $this->t('Next'),
      '#nid' => $previous_next['next'],
      '#url' => Url::fromUserInput('/node/' . $previous_next['next'])->toString(),
      '#void' => empty($previous_next['next']),
      '#cache' => $cache,
    ];

    $build['#cache']['tags'][] = 'prevnext-' . $node->bundle();

    return $build;
  }

}

==> prevnext-2.0.9.tar.gz: prevnext/src/Plugin/views/field/PrevNextLinks.php <==
<?php

namespace Drupal\prevnext\Plugin\views\field;

use Drupal\views\Plugin\views\field\FieldPluginBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\prevnext\PrevNextServiceInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\views\ResultRow;
use Drupal\Core\Url;
use Drupal\Core\Session\AccountInterface;

/**
 * A handler to provide display for the Previous and Next links.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("prevnext_links_field")
 */
class PrevNextLinks extends FieldPluginBase {

  /**
   * Returns the prevnext.service service.
   *
   * @var \Drupal\prevnext\PrevNextServiceInterface
   */
  protected $prevnext;

  /**
   * Returns the config.factory service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Returns the current_user service.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $currentUser;

  /**
   * Constructs a new PrevNextLinks instance.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin ID for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\prevnext\PrevNextServiceInterface $prevnext
   *   Interface for the main PrevNext service file.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   Defines the interface for a configuration object factory.
   * @param \Drupal\Core\Session\AccountInterface $current_user
   *    Defines an account interface which represents the current user.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, PrevNextServiceInterface $prevnext, ConfigFactoryInterface $config_factory, AccountInterface $current_user) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->prevnext = $prevnext;
    $this->configFactory = $config_factory;
    $this->currentUser = $current_user;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('prevnext.service'),
      $container->get('config.factory'),
      $container->get('current_user')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function query() {}

  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values) {
    $build = [];

    /** @var \Drupal\node\NodeInterface $node */
    $node = $this->getEntity($values);

    if (!$node) {
      return $build;
    }

    $config = $this->configFactory->get('prevnext.settings');
    $node_types = $config->get('prevnext_enabled_nodetypes');

    if (empty($node_types[$node->getType()])) {
      return $build;
    }

    if ($config->get('prevnext_premission_check') &&
      !$this->currentUser->hasPermission('view prevnext links')
    ) {
      return $build;
    }

    $previous_next = $this->prevnext->getPreviousNext($node);
    $cache = [
      'contexts' => [
        'url',
        'user.permissions',
      ],
      'tags' => [
        'config:prevnext.settings',
        'node_list',
      ],
    ];

    $build['prevnext_previous'] = [
      '#theme' => 'prevnext',
      '#direction' => 'previous',
      '#text' => $this->t('Previous'),
      '#nid' => $previous_next['prev'],
      '#url' => Url::fromUserInput('/node/' . $previous_next['prev'])->toString(),
      '#void' => empty($previous_next['prev']),
      '#cache' => $cache,
    ];

    $build['prevnext_next'] = [
      '#theme' => 'prevnext',
      '#direction' => 'next',
      '#text' => $this->t('Next'),
      '#nid' => $previous_next['next'],
      '#url' => Url::fromUserInput('/node/' . $previous_next['next'])->toString(),
      '#void' => empty($previous_next['next']),
      '#cache' => $cache,
    ];

    $build['#cache']['tags'][] = 'prevnext-' . $node->bundle();

    return $build;
  }

}
